execline: how to upgrade
Keywords: execline installation upgrade

execline
Software
skarnet.org

# What has changed in execline

## in 2.1.3.1

- skalibs dependency bumped to 2.3.6.1

## in 2.1.3.0

- skalibs dependency bumped to 2.3.6.0
- New configure option: `--shebangdir` for script creation automation.

## in 2.1.2.2

- skalibs dependency bumped to 2.3.5.1

## in 2.1.2.1

- Bugfix release, no changes

## in 2.1.2.0

- skalibs dependency bumped to 2.3.4.0
- new command: trap

## in 2.1.1.1

- skalibs dependency bumped to 2.3.3.0
- execlineb parser made into a library function, for easier inclusion in other programs

## in 2.1.1.0

- forstdin added
- forbacktickx rewritten as a wrapper around pipeline and forstdin

## in 2.1.0.0

- skalibs dependency bumped to 2.3.1.0
- foreground now sets the ? environment variable to 256 plus the signal number when its block was killed by a signal (in previous releases it used 126).
- New rules for exit codes of forx, loopwhilex, forbacktickx
- New `-e` option to loopwhilex, deprecating the `-x` option.

## in 2.0.2.1

- skalibs dependency bumped to 2.3.0.0

## in 2.0.2.0

- skalibs dependency bumped to 2.2.1.0
- New command: fdswap
- New `-D` option to backtick

## in 2.0.1.1

- skalibs dependency bumped to 2.2.0.0
- Parallel build fix

## in 2.0.1.0

- skalibs dependency bumped to 2.1.0.0
- `-u` option added to import and importas

## in 2.0.0.0

- The build system has completely changed. It is now a standard `./configure && make && sudo make install` build system. See the enclosed INSTALL file for details.
- slashpackage is not activated by default.
- shared libraries are neither built nor used by default.
- skalibs dependency bumped to 2.0.0.0
- The obsolete -E option to backtick, forx and forbacktickx is not supported anymore.
- multisubstitute does not support the "backtick" directive anymore.